@@ -14,6 +14,9 @@ class Major(models.Model):
     assigned_resident = models.IntegerField(null=True)
     assigned_nonresident = models.IntegerField(null=True)
     assigned_international = models.IntegerField(null=True)
+    assigned_freshman = models.IntegerField(null=True)
+    assigned_transfer = models.IntegerField(null=True)
+    assigned_postbac = models.IntegerField(null=True)
 
 
 class Cohort(models.Model):
@@ -25,6 +28,9 @@ class Cohort(models.Model):
     protected_group = models.BooleanField()
     active_cohort = models.BooleanField()
     assigned_count = models.IntegerField()
+    assigned_freshman = models.IntegerField(null=True)
+    assigned_transfer = models.IntegerField(null=True)
+    assigned_postbac = models.IntegerField(null=True)
 
 
 class Decision(models.Model):
@@ -169,3 +175,79 @@ class DecisionAssignment(Assignment):
                                      'decisionImportUser': self.user,
                                      'decisionNumber': self.decision_number}
                 }
+
+
+class AdminMajor(models.Model):
+    major_id = models.IntegerField()
+    major_abbr = models.CharField(max_length=32)
+    begin_academic_qtr_key_id = models.IntegerField()
+    end_academic_qtr_key_id = models.IntegerField()
+    major_pathway = models.IntegerField()
+    display_name = models.CharField(max_length=255)
+    college = models.CharField(max_length=255)
+    division = models.CharField(max_length=255)
+    dtx = models.CharField(max_length=255)
+    dtx_desc = models.CharField(max_length=255)
+    directToMajorInd = models.BooleanField()
+    directToCollegeInd = models.IntegerField()
+    majorDegreeLevel = models.IntegerField()
+    majorDegreeType = models.IntegerField()
+    assignedMajorAbbr = models.CharField(max_length=255)
+    assignedMajorDegreeLevel = models.IntegerField()
+    assignedMajorDegreeType = models.IntegerField()
+    majorAssignedName = models.CharField(max_length=255)
+    assignedMajorPathway = models.IntegerField()
+
+    def json_data(self):
+        return {
+            "id": self.major_id,
+            "majorAbbr": self.major_abbr,
+            "beginAcademicQtrKeyId": self.begin_academic_qtr_key_id,
+            "endAcademicQtrKeyId": self.end_academic_qtr_key_id,
+            "majorPathway": self.major_pathway,
+            "displayName": self.display_name,
+            "collegeCode": self.college,
+            "collegeDivision": self.division,
+            "directToXType": self.dtx,
+            "directToXDesc": self.dtx_desc,
+            "directToMajorInd": self.directToMajorInd,
+            "directToCollegeInd": self.directToCollegeInd,
+            "majorDegreeLevel": self.majorDegreeLevel,
+            "majorDegreeType": self.majorDegreeType,
+            "assignedMajorAbbr": self.assignedMajorAbbr,
+            "assignedMajorDegreeLevel": self.assignedMajorDegreeLevel,
+            "assignedMajorDegreeType": self.assignedMajorDegreeType,
+            "majorAssignedName": self.majorAssignedName,
+            "assignedMajorPathway": self.assignedMajorPathway
+        }
+
+
+class AdminCohort(models.Model):
+    academic_qtr_id = models.IntegerField()
+    cohort_number = models.IntegerField()
+    cohort_description = models.TextField()
+    cohort_residency = models.CharField(max_length=255)
+    cohort_campus = models.IntegerField()
+    cohort_application_type = models.IntegerField()
+    admit_decision = models.CharField(max_length=255)
+    protected_group = models.BooleanField()
+    enforce_exceptions = models.BooleanField()
+    active_cohort = models.BooleanField()
+    record_updated = models.DateTimeField()
+    record_update_user = models.CharField(max_length=255)
+
+    def json_data(self):
+        return {
+            "academic_qtr_id": self.academic_qtr_id,
+            "cohort_number": self.cohort_number,
+            "cohort_description": self.cohort_description,
+            "cohort_residency": self.cohort_residency,
+            "cohort_campus": self.cohort_campus,
+            "cohort_application_type": self.cohort_application_type,
+            "admit_decision": self.admit_decision,
+            "protected_group": self.protected_group,
+            "enforce_exceptions": self.enforce_exception,
+            "active_cohort": self.active_cohort,
+            "record_updated": self.record_updated,
+            "record_update_user": self.record_update_user
+        }
